OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "Mae %s wedi cyhoeddi’r calendr » %s«",
    "Hello," : "Helo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Roeddem am eich hysbysu bod %s wedi cyhoeddi'r calendr » %s«.",
    "Open »%s«" : "Agor »%s«",
    "Cheers!" : "Hwyl!",
    "Calendar" : "Calendr",
    "A Calendar app for Nextcloud" : "Ap Calendr ar gyfer Nextcloud",
    "Today" : "Heddiw",
    "Day" : "Diwrnod",
    "Week" : "Wythnos",
    "Month" : "Mis",
    "Download" : "Llwytho i lawr",
    "Delete" : "Dileu",
    "Share link" : "Rhannu dolen",
    "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
    "No users or groups" : "Dim defnyddwyr na grwpiau",
    "can edit" : "yn gallu golygu",
    "New calendar" : "Calendr newydd",
    "Cancel" : "Diddymu",
    "Show week numbers" : "Dangos rhifau wythnosau",
    "Settings & import" : "Gosodiadau a mewnforio",
    "Email" : "E-bost",
    "Unknown" : "Anhysbys",
    "never" : "byth",
    "after" : "wedi",
    "Repeat" : "Ailadrodd",
    "Monday" : "Llun",
    "More" : "Rhagor",
    "Save" : "Cadw",
    "Update" : "Diweddaru",
    "Select Date" : "Dewis Dyddiad",
    "Personal" : "Personol",
    "Details" : "Manylion",
    "Attendees" : "Mynychwyr",
    "Reminders" : "Nodau atgoffa",
    "Activity" : "Gweithred",
    "Close" : "Cau",
    "Anniversary" : "Dathliad",
    "Week {number} of {year}" : "Wythnos {number} o {year}",
    "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
    "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
    "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
    "Location" : "Lleoliad",
    "Description" : "Disgrifiad",
    "Confirmed" : "Cadarnhawyd",
    "Tentative" : "I'w gadarnhau",
    "Cancelled" : "Diddymwyd",
    "Mail" : "E-bost",
    "Play" : "Chwarae",
    "Global" : "Eang"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
